Method: ZipContainer::File#replace
- Defined in:
- lib/zip-container/file.rb
#replace(entry, src_path) ⇒ Object
:call-seq:
replace(entry, src_path)
Replaces the specified entry of the ZipContainer file with the contents of src_path (from the file system). If asked to replace any reserved files such as the special mimetype header file this method will do nothing.
333 334 335 336 |
# File 'lib/zip-container/file.rb', line 333 def replace(entry, src_path) return if reserved_entry?(entry) @container.replace(entry, src_path) end |